@@ -1,13 +1,11 @@
 import asyncio
 import warnings
 
-from http.cookies import SimpleCookie
 from inspect import isawaitable
 from typing import Any, Awaitable, Callable, MutableMapping, Union
 from urllib.parse import quote
 
-from multidict import CIMultiDict
-
+from sanic.compat import Header
 from sanic.exceptions import InvalidUsage, ServerError
 from sanic.log import logger
 from sanic.request import Request
@@ -187,7 +185,7 @@ class ASGIApp:
         instance.transport.add_task = sanic_app.loop.create_task
         instance.transport.loop = sanic_app.loop
 
-        headers = CIMultiDict(
+        headers = Header(
             [
                 (key.decode("latin-1"), value.decode("latin-1"))
                 for key, value in scope.get("headers", [])
@@ -288,11 +286,22 @@ class ASGIApp:
         """
         Write the response.
         """
-
+        headers = []
+        cookies = {}
         try:
-            headers = [
+            cookies = {
+                v.key: v
+                for _, v in list(
+                    filter(
+                        lambda item: item[0].lower() == "set-cookie",
+                        response.headers.items(),
+                    )
+                )
+            }
+            headers += [
                 (str(name).encode("latin-1"), str(value).encode("latin-1"))
                 for name, value in response.headers.items()
+                if name.lower() not in ["set-cookie"]
             ]
         except AttributeError:
             logger.error(
@@ -318,14 +327,25 @@ class ASGIApp:
                 (b"content-length", str(len(response.body)).encode("latin-1"))
             ]
 
-        if response.cookies:
-            cookies = SimpleCookie()
-            cookies.load(response.cookies)
+        if "content-type" not in response.headers:
             headers += [
-                (b"set-cookie", cookie.encode("utf-8"))
-                for name, cookie in response.cookies.items()
+                (b"content-type", str(response.content_type).encode("latin-1"))
             ]
 
+        if response.cookies:
+            cookies.update(
+                {
+                    v.key: v
+                    for _, v in response.cookies.items()
+                    if v.key not in cookies.keys()
+                }
+            )
+
+        headers += [
+            (b"set-cookie", cookie.encode("utf-8"))
+            for k, cookie in cookies.items()
+        ]
+
         await self.transport.send(
             {
                 "type": "http.response.start",
