@@ -12,8 +12,8 @@ from time import time
 
 from httptools import HttpRequestParser
 from httptools.parser.errors import HttpParserError
-from multidict import CIMultiDict
 
+from sanic.compat import Header
 from sanic.exceptions import (
     HeaderExpectationFailed,
     InvalidUsage,
@@ -304,7 +304,7 @@ class HttpProtocol(asyncio.Protocol):
     def on_headers_complete(self):
         self.request = self.request_class(
             url_bytes=self.url,
-            headers=CIMultiDict(self.headers),
+            headers=Header(self.headers),
             version=self.parser.get_http_version(),
             method=self.parser.get_method().decode(),
             transport=self.transport,
